==> aws-java-sdk-directory-1.11.63-sources.jar: com/amazonaws/services/directory/model/GetSnapshotLimitsRequest.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.directory.model;

import java.io.Serializable;
import com.amazonaws.AmazonWebServiceRequest;

/**
 * <p>
 * Contains the inputs for the <a>GetSnapshotLimits</a> operation.
 * </p>
 */
public class GetSnapshotLimitsRequest extends com.amazonaws.AmazonWebServiceRequest implements Serializable, Cloneable {

    /**
     * <p>
     * Contains the identifier of the directory to obtain the limits for.
     * </p>
     */
    private String directoryId;

    /**
     * <p>
     * Contains the identifier of the directory to obtain the limits for.
     * </p>
     * 
     * @param directoryId
     *        Contains the identifier of the directory to obtain the limits for.
     */

    public void setDirectoryId(String directoryId) {
        this.directoryId = directoryId;
    }

    /**
     * <p>
     * Contains the identifier of the directory to obtain the limits for.
     * </p>
     * 
     * @return Contains the identifier of the directory to obtain the limits for.
     */

    public String getDirectoryId() {
        return this.directoryId;
    }

    /**
     * <p>
     * Contains the identifier of the directory to obtain the limits for.
     * </p>
     * 
     * @param directoryId
     *        Contains the identifier of the directory to obtain the limits for.
     * @return Returns a reference to this object so that method calls can be chained together.
     */

    public GetSnapshotLimitsRequest withDirectoryId(String directoryId) {
        setDirectoryId(directoryId);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getDirectoryId() != null)
            sb.append("DirectoryId: " + getDirectoryId());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof GetSnapshotLimitsRequest == false)
            return false;
        GetSnapshotLimitsRequest other = (GetSnapshotLimitsRequest) obj;
        if (other.getDirectoryId() == null ^ this.getDirectoryId() == null)
            return false;
        if (other.getDirectoryId() != null && other.getDirectoryId().equals(this.getDirectoryId()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode + ((getDirectoryId() == null) ? 0 : getDirectoryId().hashCode());
        return hashCode;
    }

    @Override
    public GetSnapshotLimitsRequest clone() {
        return (GetSnapshotLimitsRequest) super.clone();
    }
}

==> aws-java-sdk-directory-1.11.75-sources.jar: com/amazonaws/services/directory/model/GetSnapshotLimitsRequest.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.directory.model;

import java.io.Serializable;
import com.amazonaws.AmazonWebServiceRequest;

/**
 * <p>
 * Contains the inputs for the <a>GetSnapshotLimits</a> operation.
 * </p>
 * 
 * @see <a href="http://docs.aws.amazon.com/goto/WebAPI/ds-2015-04-16/GetSnapshotLimits"/>AWS API Documentation</a>
 */
public class GetSnapshotLimitsRequest extends com.amazonaws.AmazonWebServiceRequest implements Serializable, Cloneable {

    /**
     * <p>
     * Contains the identifier of the directory to obtain the limits for.
     * </p>
     */
    private String directoryId;

    /**
     * <p>
     * Contains the identifier of the directory to obtain the limits for.
     * </p>
     * 
     * @param directoryId
     *        Contains the identifier of the directory to obtain the limits for.
     */

    public void setDirectoryId(String directoryId) {
        this.directoryId = directoryId;
    }

    /**
     * <p>
     * Contains the identifier of the directory to obtain the limits for.
     * </p>
     * 
     * @return Contains the identifier of the directory to obtain the limits for.
     */

    public String getDirectoryId() {
        return this.directoryId;
    }

    /**
     * <p>
     * Contains the identifier of the directory to obtain the limits for.
     * </p>
     * 
     * @param directoryId
     *        Contains the identifier of the directory to obtain the limits for.
     * @return Returns a reference to this object so that method calls can be chained together.
     */

    public GetSnapshotLimitsRequest withDirectoryId(String directoryId) {
        setDirectoryId(directoryId);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getDirectoryId() != null)
            sb.append("DirectoryId: ").append(getDirectoryId());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof GetSnapshotLimitsRequest == false)
            return false;
        GetSnapshotLimitsRequest other = (GetSnapshotLimitsRequest) obj;
        if (other.getDirectoryId() == null ^ this.getDirectoryId() == null)
            return false;
        if (other.getDirectoryId() != null && other.getDirectoryId().equals(this.getDirectoryId()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode + ((getDirectoryId() == null) ? 0 : getDirectoryId().hashCode());
        return hashCode;
    }

    @Override
    public GetSnapshotLimitsRequest clone() {
        return (GetSnapshotLimitsRequest) super.clone();
    }

}
